require 'helper'

class TestTruth < Test::Unit::TestCase
  include Truth
  context 'Client' do
    setup do
      path = configs_folder('default')
      @config = Truth::Config.new(path)
      @client = Client.new(@config)
      assert @client
    end

    context 'get_command' do
      {
        "server.blade11.add_roles" => :add_roles,
        "server.blade11.add_info"  => :add_info,
        "server.blade11.set_environment" => :set_environment
      }.each do |channel, command|
        should "return #{command}" do
          assert_equal Client.get_command(channel), command
        end
      end
    end
  end


  context 'Config' do
    context 'config.yml' do
      setup do
        path = configs_folder('default')
        @config = Truth::Config.new(path)
      end

      should "set the config_folder" do
        assert_not_nil @config.config_folder, 'configs/default'
      end

      should "read the environment" do
        assert_equal @config.environment, 'test'
      end

      should "read redis ip" do
        assert_equal @config.redis_ip, '127.0.0.1'
      end

      should "read the hostname" do
        assert_equal @config.hostname, 'testhost'
      end
    end
  end

  context 'data.yml' do
    setup do
      `cp -r #{configs_folder('default')}/ #{configs_folder('write_test')}`
      path = configs_folder('write_test')
      @config = Truth::Config.new(path)
    end

    teardown do
      `rm -rf #{configs_folder('write_test')}`
    end

    should "read the roles" do
      assert_equal @config.current_roles , []
    end

    should "write roles" do
      @config.add_roles ['mysql_server']
      assert_equal ['mysql_server'], @config.current_roles
    end

    should "read info" do
      assert_equal @config.info('solr_version'), nil
    end

    should "write info" do
      @config.add_info('solr_version', 33)
      assert_equal @config.info('solr_version'), 33
    end
  end
end
